@@ -5,8 +5,7 @@
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
-#ifndef KDEPIM_RECENTADDRESSES_H
-#define KDEPIM_RECENTADDRESSES_H
+#pragma once
 
 #include "pimcommonakonadi_export.h"
 #include <KContacts/Addressee>
@@ -41,7 +40,7 @@ public:
      * Note: an entry doesn't have to be one email address, it can be multiple,
      * like "Foo <foo@bar.org>, Bar Baz <bar@baz.org>".
      */
-    Q_REQUIRED_RESULT QStringList addresses() const;
+    [[nodiscard]] QStringList addresses() const;
 
     /**
      * Adds an entry to the list.
@@ -59,7 +58,7 @@ public:
     /**
      * @returns the current maximum number of entries.
      */
-    Q_REQUIRED_RESULT int maxCount() const;
+    [[nodiscard]] int maxCount() const;
 
     /**
      * Loads the list of recently used addresses from the configfile.
@@ -79,13 +78,11 @@ public:
     void clear();
 
 private:
-    explicit RecentAddresses(KConfig *config = nullptr);
-    void adjustSize();
+    PIMCOMMONAKONADI_NO_EXPORT explicit RecentAddresses(KConfig *config = nullptr);
+    PIMCOMMONAKONADI_NO_EXPORT void adjustSize();
 
     KContacts::Addressee::List m_addresseeList;
 
     int m_maxCount;
 };
 }
-
-#endif
